@@ -307,7 +307,7 @@ RPMS_consent_colname: Consent
 '''
 
     if args.s3:
-        if 'rpms' in args.source:
+        if 'rpms' in args.sources:
             s3_lines = f'''AWS_BUCKET_NAME: prescient-test
 AWS_BUCKET_ROOT: TEST_PHOENIX_ROOT_PRESCIENT'''
         else:
